translate.convert.po2dtd.po2dtd

Package translate :: Package convert :: Module po2dtd :: Class po2dtd |
[hide private]
[frames] | no frames]

# Class po2dtd

source code

this is a convertor class that creates a new dtd file based on a po file without a template

Instance Methods | [hide private]
convertcomments(self, inputunit, dtdunit) | source code
convertstrings(self, inputunit, dtdunit) | source code
convertunit(self, inputunit) | source code
convertstore(self, inputstore, includefuzzy=False) | source code